#
# spec file for package aspell
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           aspell
Version:        0.60.6.1
Release:        19.19
Summary:        A Free and Open Source Spell Checker
License:        GFDL-1.1+ and LGPL-2.1 and HPND and SUSE-BSD-Mark-Modifications
Group:          Productivity/Text/Spell
Url:            http://aspell.net/
Source0:        ftp://ftp.gnu.org/gnu/aspell/%{name}-%{version}.tar.gz
Source100:      baselibs.conf
# PATCH-FIX-OPENSUSE aspell-strict-aliasing.patch pnemec@suse.cz -- Fix gcc strict aliasing warnings
Patch0:         aspell-strict-aliasing.patch
# PATCH-FIX-OPENSUSE aspell-quotes.patch lmichnovic@suse.cz -- Fix command execution in script "run-with-aspell"
Patch1:         aspell-quotes.patch
# PATCH-FIX-OPENSUSE aspell-epmty_file.patch bnc#266130 lmichnovic@suse.cz -- Fix SIGSEV when checking empty file
Patch2:         aspell-epmty_file.patch
# PATCH-FIX-UPSTREAM aspell-automake-1.13.patch pgajdos@suse.cz -- fix build with new automake
Patch3:         aspell-automake-1.13.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  ncurses-devel
Requires(post): info
Requires(preun): info
Recommends:     aspell-en
Suggests:       aspell-ispell
Suggests:       aspell-spell
Provides:       pspell = %{version}
Obsoletes:      pspell < %{version}
# bug437293
%ifarch ppc64
Obsoletes:      aspell-64bit
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNU Aspell is a spell checker designed to eventually replace Ispell. It
can be used as a library or as an independent spell checker.

Its main feature is that it does a much better job of coming up with
possible suggestions than just about any other spell checker available
for the English language, including Ispell and Microsoft Word. It also
has many other technical enhancements over Ispell, such as using shared
memory for dictionaries and intelligently handling personal
dictionaries when more than one Aspell process is open at once.

%package devel
Summary:        Include Files and Libraries Mandatory for Development with aspell
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libaspell15 = %{version}
Requires:       libpspell15 = %{version}
Requires(post): info
Requires(preun): info
Provides:       pspell-devel = %{version}
Obsoletes:      pspell-devel < %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require aspell.

%package ispell
Summary:        GNU Aspell - Ispell compatibility
Group:          Productivity/Text/Spell
Requires:       %{name} = %{version}
Conflicts:      ispell

%description ispell
GNU Aspell is a spell checker designed to eventually replace Ispell. It
can be used as a library or as an independent spell checker.

This package contains an ispell script for compatibility reasons so that
programs that expect the "ispell" command will work correctly.

%package spell
Summary:        GNU Aspell - Spell compatibility
Group:          Productivity/Text/Spell
Requires:       %{name} = %{version}
Provides:       spell

%description spell
GNU Aspell is a spell checker designed to eventually replace Ispell. It
can be used as a library or as an independent spell checker.

This package contains a spell script for compatibility reasons so that programs
that expect the "spell" command will work correctly.

%package -n libaspell15
Summary:        GNU Aspell Library
Group:          System/Libraries

%description -n libaspell15
GNU Aspell is a spell checker designed to eventually replace Ispell. It
can be used as a library or as an independent spell checker.

This package contains the aspell library.

%package -n libpspell15
Summary:        GNU Aspell - Pspell Compatibility Library
Group:          System/Libraries

%description -n libpspell15
GNU Aspell is a spell checker designed to eventually replace Ispell. It
can be used as a library or as an independent spell checker.

This package contains the pspell compatibility library.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3

%build
autoreconf -fiv
export CXXFLAGS="%optflags `ncursesw6-config --cflags`"
#this is an ugly kludge , don't look :-)
export LDFLAGS="`ncursesw6-config --libs`"
%configure \
%if 0%{?suse_version} > 1210
    --enable-curses="-lncursesw" \
%endif
 --disable-rpath

make %{?_smp_mflags}

%install
%if 0%{?suse_version} >= 1120
%make_install
%else
make DESTDIR=%{buildroot} install
%endif
# Links for compatibility reasons (ispell and spell)
ln -s %{_libdir}/aspell-0.60/ispell %{buildroot}%{_bindir}
ln -s %{_libdir}/aspell-0.60/spell %{buildroot}%{_bindir}
find %{buildroot} -name "*.la" -type f -print -delete
%fdupes -s %{buildroot}

%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}-dev.info%{ext_info}

%preun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}-dev.info%{ext_info}

%post -n libaspell15 -p /sbin/ldconfig

%postun -n libaspell15 -p /sbin/ldconfig

%post -n libpspell15 -p /sbin/ldconfig

%postun -n libpspell15 -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc COPYING README TODO
%doc manual/aspell.html/
%{_bindir}/aspell
%{_bindir}/aspell-import
%{_bindir}/pre*
%{_bindir}/run-with-aspell
%{_bindir}/word-list-compress
%doc %{_infodir}/%{name}.info%{ext_info}
%doc %{_mandir}/man1/*.1%{ext_man}
%exclude %{_mandir}/man1/pspell-config.1%{ext_man}

%files devel
%defattr(-,root,root,-)
%doc manual/aspell-dev.html/
%{_bindir}/pspell-config
%{_includedir}/pspell/
%{_includedir}/*.h
%{_libdir}/libaspell.so
%{_libdir}/libpspell.so
%doc %{_infodir}/%{name}-dev.info%{ext_info}
%doc %{_mandir}/man1/pspell-config.1%{ext_man}

%files ispell
%defattr(-,root,root,-)
%{_bindir}/ispell

%files spell
%defattr(-,root,root,-)
%{_bindir}/spell

%files -n libaspell15
%defattr(-,root,root,-)
%{_libdir}/aspell-0.60/
%{_libdir}/libaspell.so.15*

%files -n libpspell15
%defattr(-,root,root,-)
%{_libdir}/libpspell.so.15*

%changelog
* Mon Apr 14 2014 pgajdos@suse.com
- baselibs.conf: libaspell15 [bnc#873440]
  obsoletes "aspell-<targettype> <= <version>"
  provides "aspell-<targettype> = <version>"
* Wed Mar  6 2013 pgajdos@suse.com
- license GFDL-1.1+ and LGPL-2.1 and HPND and SUSE-BSD-Mark-Modifications
  [bnc#777131]
* Wed Mar  6 2013 cfarrell@suse.com
- license update: GFDL-1.1+ and LGPL-2.1 and HPND and BSD-3-Clause
  SDPX
* Mon Mar  4 2013 pgajdos@suse.com
- license GFDL-1.1+ and LGPL-2.1 and HPND and BSD-Mark-Modifications
* Thu Feb 28 2013 pgajdos@suse.com
- fix build with new automake
  * automake-1.13.patch
* Tue Oct  9 2012 pgajdos@suse.com
- license FDL-1.1+ and LGPL-2.1 and HPND and BSD-Mark-Modifications
* Fri Feb 24 2012 crrodriguez@opensuse.org
- Build C++ code with -fvisibility-inlines-hidden
- Fix ncurses linkage.
* Sat Jan 28 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Tue Nov 22 2011 pgajdos@suse.com
- add -ltinfo
* Sun Oct  2 2011 asterios.dramis@gmail.com
- update to version 0.60.6.1
  * Update to Automake 1.10.3.
  * Fix a bug which caused a race condition (leading to a likely crash)
    when two threads try to update the dictionary cache at the same
    time.
  * Make it very clear that compiling Aspell with NDEBUG is a bad idea
    (see `http://aspell.net/ndebug.html') by outputting a warning when
    building with NDEBUG defined.
  * Numerous other minor updates and bug fixes.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPL-2.1+.
  * Splitted the package according to the shared library packaging policy
    (added libaspell15 and libpspell15 sub-packages).
  * Added descriptions for the patches based on openSUSE guidelines.
  * Suggest also aspell-spell sub-package.
  * Added versioned Provides:/Obsoletes: for pspell and pspell-devel (rpmlint
    warning fix).
  * Removed libstdc++-devel from Requires: of aspell-devel (not needed).
  * Improved summaries and descriptions.
  * Clean up in %%build, %%install and %%files sections.
  * Install the "spell" script provided by the package for compatibility
    reasons (added a aspell-spell sub-package containing this script and moved
    the Provides: entry for "spell" into this package).
  * Use %%fdupes macro to fix rpmlint warning about duplicate files.
  * Use %%install_info_delete in %%preun instead of %%postun section.
  * Add pspell-config.1 man page to the aspell-devel sub-package instead of
    aspell.
- Removed the following patches (fixed upstream):
  * aspell-iterator-after-erase.patch
  * aspell-make-static-filters.patch
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Jul 20 2009 pgajdos@suse.cz
- fixed invalid iterator [bnc#523345]
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Nov 20 2008 pgajdos@suse.cz
- fixed wrong static filter handling [bnc#441008]
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Sep  9 2008 pgajdos@suse.cz
- created aspell-ispell subpackage [bnc#165023]
* Fri Jul 25 2008 lmichnovic@suse.cz
- update to version 0.60.6
  * bugfix release
- obsoletes *duplicate_name.patch, *gcc4_3.patch
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Oct 26 2007 nadvornik@suse.cz
- fixed to compile with gcc 4.3 (gcc4_3.patch)
* Wed Aug 22 2007 lmichnovic@suse.cz
- defining ncurses_wide library for configure to enable wide
  UTF-8 characters [#266153]
* Thu Aug 16 2007 lmichnovic@suse.cz
- fixed SIGSEV when checking empty file(epmty_file.patch) [#266130]
- using parallel build
* Thu Aug 16 2007 lmichnovic@suse.cz
- changed dict- and data-dir back to /usr/{%%lib} because dictionary
  files depends on endian.
- fixed command execution in script "run-with-aspell" (quotes.patch)
* Wed Aug 15 2007 lmichnovic@suse.cz
- using lang macro
- not using obsoleted %%run_ldconfig macro
- defining dict- and data-dir to arch independent directory which
  allow made dictionaries noarch and save 30 MB on BiArch media
* Sat Mar 31 2007 rguenther@suse.de
- add ncurses-devel BuildRequires.
* Sat Mar 31 2007 aj@suse.de
- Cleanup BuildRequires.
* Thu Jan 11 2007 lmichnovic@suse.cz
- gettextize is needed before autoreconf
* Thu Jan 11 2007 lmichnovic@suse.cz
- update to version 0.60.5
  * Compile fix for gcc 4.1 (obsoletes gcc-warning.patch)
  * Updated to Gettext 0.16.1, Libtool 1.5.22, Automake 1.10,
    Autoconf 2.61
  * Documentation improvements, including an updated `man' page.
  * Complain if more than one file is specified when checking
    files using the `aspell check' command, rather than ignoring
    the other files.
  * Large number of bug fixes.
* Tue Sep  5 2006 pnemec@suse.cz
- changed Requires to aspell-en to Recommends
* Wed Aug  2 2006 pnemec@suse.cz
- fixed wrong parametr name in header file [#175555]
* Fri Jun 30 2006 pnemec@suse.cz
- updated to 0.60.4
  primary a bug fix release
* Mon Mar 20 2006 pnemec@suse.cz
- removed virtual package dependency
- added aspell-en to Requires #158675
* Tue Feb 21 2006 aj@suse.de
- Fix Require for devel package.
* Tue Feb  7 2006 pnemec@suse.cz
- fixed virtual package name
* Fri Feb  3 2006 pnemec@suse.cz
- added virtual package aspell_dictionary to Requires
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  2 2006 pnemec@suse.cz
- fixed gcc strict aliasing warnings
* Tue Oct  4 2005 pnemec@suse.cz
- fixed gcc warning and aspell-devel requires
* Wed Jun 29 2005 ltinkl@suse.cz
- update to 0.60.3
* Tue Mar 15 2005 ltinkl@suse.cz
- update to 0.60.2 which fixes some critical bugs (munch-list, better
  support for non-English languages)
* Tue Nov 30 2004 ro@suse.de
- fix file list
* Mon Nov 29 2004 ro@suse.de
- fix libdir usage
* Mon Nov 29 2004 ltinkl@suse.cz
- update to 0.60.1.1
* Fri Nov 26 2004 ltinkl@suse.cz
- updated to 0.60
- correctly install info pages
- package the HTML manuals
* Fri Aug 13 2004 lnussel@suse.de
- apply corrected patch for #42197
* Thu Jun 24 2004 ltinkl@suse.cz
- fix #42197
* Mon Feb 16 2004 ltinkl@suse.cz
- update to 0.50.5
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Thu Oct 23 2003 ltinkl@suse.cz
- update to latest stable version (0.50.4.1)
- throw away unused patch
* Wed Jul 23 2003 ltinkl@suse.cz
- updated sources to 0.50.3
- package ChangeLog instead of empty TODO
- removed unused patch
* Wed May 21 2003 pmladek@suse.cz
- fixed installation of documentation that rpm does not complain
  about unpacked files
* Tue Feb 25 2003 kukuk@suse.de
- Include assert.h
* Fri Jan 31 2003 pmladek@suse.cz
- fixed to link the libraries with -lstdc++
* Wed Nov 20 2002 pmladek@suse.cz
- fixed invalid declaration which breaks building with gcc-3.3
- used x-devel-packages in neededforbuild instead of the obsolete xf86
* Fri Nov  1 2002 pmladek@suse.cz
- updated to version 0.50.2:
  * merged with pspell
  * changed way to handle dictionaries
  * added aspell-import script to convert old dictionaries
  * pspell ABI is now part of aspell except that the name of everything has
    changed due to the renaming of pspell to aspell
  * provided pspell backward compatibility header file
  * the name of the language-tag option has changed to lang
  * backward compatible the language-tag option will still work
  * english dictionaries are built from separate package
  * see more details in /usr/share/doc/packages/aspell/README
- removed obsolete config files
- removed obsolete patches for automake, gcc3.x and x86_64
- fixed list of documentation to install
- fixed to compile example with gcc
- fixed problem with locking on nfs
* Fri Aug 30 2002 pmladek@suse.cz
- fixed dependency of the devel subpackage on the main package (used %%version)
* Wed May 29 2002 meissner@suse.de
- The hashing code did not halt in some hash bucket size cases
  which were reached due to slightly different floating point
  handling in x86_64.
  Now using integer arithmetic.
* Mon Apr 15 2002 pmladek@suse.cz
- fixed to compile with gcc-3.1
* Thu Jan 10 2002 pmladek@suse.cz
- used macro %%{_libdir} to fix for lib64
* Fri Dec 14 2001 pmladek@suse.cz
- updated to version .33.7.1:
  * Minor manual fixes
  * compile fix for gcc 3.0 and Solaris
- added the patch aspell-.33-fix2.diff from sourceforge
- removed obsolete axp patch
- fixed file list
* Thu Oct 18 2001 pmladek@suse.cz
- moved spell to /usr/bin (default path)
- added spell to Provides
- added aspell-en to Requires because of spell
* Thu Oct  4 2001 schwab@suse.de
- Fix for automake 1.5.
- Avoid macro in Version tag.
* Mon Aug 27 2001 pmladek@suse.cz
- fixed to compile on axp:
  * fixed declaration of friend classes
* Fri Aug 17 2001 pmladek@suse.cz
- fixed file list
- added ed and dialog to neededforbuild through tetex
* Thu Aug 16 2001 pmladek@suse.cz
- updated to version 0.33.7
- fixed documentation
* Tue Jun 26 2001 schwab@suse.de
- Remove -I$(includedir).
* Mon Jun 11 2001 ro@suse.de
- libtoolize to build
* Wed May 30 2001 pmladek@suse.cz
- package created
- added start script and configurations for each spelling and jargon
